# -*- coding: UTF-8 -*-
"""
@Project  : admin_ckeditor
@File     : widgets.py
@IDE      : PyCharm
@Author   : Tan Jianbin
@Email    : bj.t@foxmail.com
@Date     : 2024/5/23 8:56
@Function :
"""
from django.template import loader
from django.forms import ClearableFileInput
from django.utils.safestring import mark_safe


class ImageCroppingInput(ClearableFileInput):
    template_name = "image_cropping.html"

    class Media:
        css = {
            "all": [
                "css/bootstrap.min.css",
                "css/cropper.min.css",
                "css/image_cropping.css",
            ]
        }

        js = [
            "js/bootstrap.min.js",
            "js/cropper.min.js",
            "js/jquery-3.7.1.min.js",
        ]

    def render(self, name, value, attrs=None, renderer=None):
        context = self.get_context(name, value, attrs)
        template = loader.get_template(self.template_name).render(context)
        return mark_safe(template)



from django import forms
from django.db import models

from django_image_cropping.widgets import ImageCroppingInput


class ImageCroppingField(models.ImageField):

    def formfield(self, **kwargs):
        defaults = {
            'form_class': ImageCroppingFormField,
        }
        defaults.update(kwargs)
        return super(ImageCroppingField, self).formfield(**defaults)


class ImageCroppingFormField(forms.ImageField):
    def __init__(self, **kwargs):
        kwargs.update({'widget': ImageCroppingInput()})
        super(ImageCroppingFormField, self).__init__(**kwargs)



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="django-image-crop",
    version="0.0.1",
    author="bj.tr",
    author_email="bj.t@foxmail.com",
    description="Image cropping plugin, can be directly applied to django admin.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(),
    include_package_data=True,
    keyword=["django-image-crop", "django", "image", "crop", "cropper"],
    classifiers=[
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Framework :: Django :: 3.0",
        "Framework :: Django :: 4.0",
        "Framework :: Django :: 5.0",
    ],
)